==> ejc-middlemeasurement-impl-3.0.0-20220929.033104-135-sources.jar: com/ejianc/business/middlemeasurement/bean/VisaclaimaccountEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.VisaclaimaccountdetailEntity;
/**
 * 总包签证索赔台账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_visaclaimaccount")
public class VisaclaimaccountEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="happen_time")
    private java.util.Date happenTime; // 发生时间
    @TableField(value="in_submit_amount_our")
    private java.math.BigDecimal inSubmitAmountOur; // 我方报送金额
    @TableField(value="in_confirm_amount_opposite")
    private java.math.BigDecimal inConfirmAmountOpposite; //  对方确认金额
    @TableField(value="in_amount_payable")
    private java.math.BigDecimal inAmountPayable; // 应付金额
    @TableField(value="in_amount_real_pay")
    private java.math.BigDecimal inAmountRealPay; // 实付金额
    @TableField(value="ex_submit_amount_our")
    private java.math.BigDecimal exSubmitAmountOur; // 我方报送金额
    @TableField(value="ex_confirm_amount_opposite")
    private java.math.BigDecimal exConfirmAmountOpposite; //  对方确认金额
    @TableField(value="ex_amount_payable")
    private java.math.BigDecimal exAmountPayable; // 应付金额
    @TableField(value="ex_amount_real_pay")
    private java.math.BigDecimal exAmountRealPay; // 实付金额
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="visaclaimaccountdetailService",pidName = "mid")
    private List<VisaclaimaccountdetailEntity> visaclaimaccountdetailEntities = new ArrayList<>(); // 总包签证索赔台账子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 发生时间
     */
    public java.util.Date getHappenTime() {
        return happenTime;
    }

    /**
     * 发生时间
     */
    public void setHappenTime(java.util.Date happenTime) {
        this.happenTime = happenTime;
    }
    /**
     * 我方报送金额
     */
    public java.math.BigDecimal getInSubmitAmountOur() {
        return inSubmitAmountOur;
    }

    /**
     * 我方报送金额
     */
    public void setInSubmitAmountOur(java.math.BigDecimal inSubmitAmountOur) {
        this.inSubmitAmountOur = inSubmitAmountOur;
    }
    /**
     *  对方确认金额
     */
    public java.math.BigDecimal getInConfirmAmountOpposite() {
        return inConfirmAmountOpposite;
    }

    /**
     *  对方确认金额
     */
    public void setInConfirmAmountOpposite(java.math.BigDecimal inConfirmAmountOpposite) {
        this.inConfirmAmountOpposite = inConfirmAmountOpposite;
    }
    /**
     * 应付金额
     */
    public java.math.BigDecimal getInAmountPayable() {
        return inAmountPayable;
    }

    /**
     * 应付金额
     */
    public void setInAmountPayable(java.math.BigDecimal inAmountPayable) {
        this.inAmountPayable = inAmountPayable;
    }
    /**
     * 实付金额
     */
    public java.math.BigDecimal getInAmountRealPay() {
        return inAmountRealPay;
    }

    /**
     * 实付金额
     */
    public void setInAmountRealPay(java.math.BigDecimal inAmountRealPay) {
        this.inAmountRealPay = inAmountRealPay;
    }
    /**
     * 我方报送金额
     */
    public java.math.BigDecimal getExSubmitAmountOur() {
        return exSubmitAmountOur;
    }

    /**
     * 我方报送金额
     */
    public void setExSubmitAmountOur(java.math.BigDecimal exSubmitAmountOur) {
        this.exSubmitAmountOur = exSubmitAmountOur;
    }
    /**
     *  对方确认金额
     */
    public java.math.BigDecimal getExConfirmAmountOpposite() {
        return exConfirmAmountOpposite;
    }

    /**
     *  对方确认金额
     */
    public void setExConfirmAmountOpposite(java.math.BigDecimal exConfirmAmountOpposite) {
        this.exConfirmAmountOpposite = exConfirmAmountOpposite;
    }
    /**
     * 应付金额
     */
    public java.math.BigDecimal getExAmountPayable() {
        return exAmountPayable;
    }

    /**
     * 应付金额
     */
    public void setExAmountPayable(java.math.BigDecimal exAmountPayable) {
        this.exAmountPayable = exAmountPayable;
    }
    /**
     * 实付金额
     */
    public java.math.BigDecimal getExAmountRealPay() {
        return exAmountRealPay;
    }

    /**
     * 实付金额
     */
    public void setExAmountRealPay(java.math.BigDecimal exAmountRealPay) {
        this.exAmountRealPay = exAmountRealPay;
    }
    
    /**
     * 总包签证索赔台账子表
     */
    public List<VisaclaimaccountdetailEntity> getVisaclaimaccountdetailEntities() {
        return visaclaimaccountdetailEntities;
    }

    /**
     * 总包签证索赔台账子表
     */
    public void setVisaclaimaccountdetailEntities(List<VisaclaimaccountdetailEntity> visaclaimaccountdetailEntities) {
        this.visaclaimaccountdetailEntities = visaclaimaccountdetailEntities;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221021.114700-173-sources.jar: com/ejianc/business/middlemeasurement/bean/VisaclaimaccountEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;
/**
 * 总包签证索赔台账
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_visaclaimaccount")
public class VisaclaimaccountEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="contract")
    private java.lang.Long contract; // 合同
    @TableField(value="contract_name")
    private java.lang.String contractName; // 合同名称
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="agent_id")
    private java.lang.Long agentId; // 经办人
    @TableField(value="agent_name")
    private java.lang.String agentName; // 经办人姓名
    @TableField(value="happen_time")
    private java.util.Date happenTime; // 发生时间
    @TableField(value="in_submit_amount_our")
    private java.math.BigDecimal inSubmitAmountOur; // 我方报送金额
    @TableField(value="in_confirm_amount_opposite")
    private java.math.BigDecimal inConfirmAmountOpposite; //  对方确认金额
    @TableField(value="in_amount_payable")
    private java.math.BigDecimal inAmountPayable; // 应付金额
    @TableField(value="in_amount_real_pay")
    private java.math.BigDecimal inAmountRealPay; // 实付金额
    @TableField(value="ex_submit_amount_our")
    private java.math.BigDecimal exSubmitAmountOur; // 我方报送金额
    @TableField(value="ex_confirm_amount_opposite")
    private java.math.BigDecimal exConfirmAmountOpposite; //  对方确认金额
    @TableField(value="ex_amount_payable")
    private java.math.BigDecimal exAmountPayable; // 应付金额
    @TableField(value="ex_amount_real_pay")
    private java.math.BigDecimal exAmountRealPay; // 实付金额
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="visaclaimaccountdetailService",pidName = "mid")
    private List<VisaclaimaccountdetailEntity> visaclaimaccountdetailEntities = new ArrayList<>(); // 总包签证索赔台账子表

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 合同
     */
    public java.lang.Long getContract() {
        return contract;
    }

    /**
     * 合同
     */
    public void setContract(java.lang.Long contract) {
        this.contract = contract;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 经办人
     */
    public java.lang.Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人
     */
    public void setAgentId(java.lang.Long agentId) {
        this.agentId = agentId;
    }
    /**
     * 经办人姓名
     */
    public java.lang.String getAgentName() {
        return agentName;
    }

    /**
     * 经办人姓名
     */
    public void setAgentName(java.lang.String agentName) {
        this.agentName = agentName;
    }
    /**
     * 发生时间
     */
    public java.util.Date getHappenTime() {
        return happenTime;
    }

    /**
     * 发生时间
     */
    public void setHappenTime(java.util.Date happenTime) {
        this.happenTime = happenTime;
    }
    /**
     * 我方报送金额
     */
    public java.math.BigDecimal getInSubmitAmountOur() {
        return inSubmitAmountOur;
    }

    /**
     * 我方报送金额
     */
    public void setInSubmitAmountOur(java.math.BigDecimal inSubmitAmountOur) {
        this.inSubmitAmountOur = inSubmitAmountOur;
    }
    /**
     *  对方确认金额
     */
    public java.math.BigDecimal getInConfirmAmountOpposite() {
        return inConfirmAmountOpposite;
    }

    /**
     *  对方确认金额
     */
    public void setInConfirmAmountOpposite(java.math.BigDecimal inConfirmAmountOpposite) {
        this.inConfirmAmountOpposite = inConfirmAmountOpposite;
    }
    /**
     * 应付金额
     */
    public java.math.BigDecimal getInAmountPayable() {
        return inAmountPayable;
    }

    /**
     * 应付金额
     */
    public void setInAmountPayable(java.math.BigDecimal inAmountPayable) {
        this.inAmountPayable = inAmountPayable;
    }
    /**
     * 实付金额
     */
    public java.math.BigDecimal getInAmountRealPay() {
        return inAmountRealPay;
    }

    /**
     * 实付金额
     */
    public void setInAmountRealPay(java.math.BigDecimal inAmountRealPay) {
        this.inAmountRealPay = inAmountRealPay;
    }
    /**
     * 我方报送金额
     */
    public java.math.BigDecimal getExSubmitAmountOur() {
        return exSubmitAmountOur;
    }

    /**
     * 我方报送金额
     */
    public void setExSubmitAmountOur(java.math.BigDecimal exSubmitAmountOur) {
        this.exSubmitAmountOur = exSubmitAmountOur;
    }
    /**
     *  对方确认金额
     */
    public java.math.BigDecimal getExConfirmAmountOpposite() {
        return exConfirmAmountOpposite;
    }

    /**
     *  对方确认金额
     */
    public void setExConfirmAmountOpposite(java.math.BigDecimal exConfirmAmountOpposite) {
        this.exConfirmAmountOpposite = exConfirmAmountOpposite;
    }
    /**
     * 应付金额
     */
    public java.math.BigDecimal getExAmountPayable() {
        return exAmountPayable;
    }

    /**
     * 应付金额
     */
    public void setExAmountPayable(java.math.BigDecimal exAmountPayable) {
        this.exAmountPayable = exAmountPayable;
    }
    /**
     * 实付金额
     */
    public java.math.BigDecimal getExAmountRealPay() {
        return exAmountRealPay;
    }

    /**
     * 实付金额
     */
    public void setExAmountRealPay(java.math.BigDecimal exAmountRealPay) {
        this.exAmountRealPay = exAmountRealPay;
    }
    
    /**
     * 总包签证索赔台账子表
     */
    public List<VisaclaimaccountdetailEntity> getVisaclaimaccountdetailEntities() {
        return visaclaimaccountdetailEntities;
    }

    /**
     * 总包签证索赔台账子表
     */
    public void setVisaclaimaccountdetailEntities(List<VisaclaimaccountdetailEntity> visaclaimaccountdetailEntities) {
        this.visaclaimaccountdetailEntities = visaclaimaccountdetailEntities;
    }
}
